@@ -24,6 +24,8 @@ package IPC::PrettyPipe::Arg;
 use Carp;
 
 use Moo;
+use String::ShellQuote;
+
 use Types::Standard qw[ Str ];
 
 has name => (
@@ -82,6 +84,11 @@ sub BUILDARGS {
     return {@_};
 }
 
+sub quoted_name {  shell_quote( $_[0]->name )  }
+
+sub quoted_value {  shell_quote( $_[0]->value )  }
+
+
 # for render templates
 sub has_blank_value {
 
@@ -232,6 +239,38 @@ Get or set the value of the C<pfx> attribute.
 
 Get or set the value of the C<sep> attribute.
 
+=item B<name>
+
+  $name = $self->name;
+
+The argument's name;
+
+=item B<quoted_name>
+
+  $name = $self->quoted_name;
+
+The argument's name, appropriately quoted for passing as a
+single word to a Bourne compatible shell.
+
+=item B<value>
+
+  $value = $self->value;
+
+The argument's value;
+
+=item B<quoted_value>
+
+  $value = $self->quoted_value;
+
+The argument's value, appropriately quoted for passing as a
+single word to a Bourne compatible shell.
+
+=item B<has_value>
+
+  $bool = $self->has_value
+
+Returns true if the argument has been assigned a value.
+
 =item B<has_blank_value>
 
   $bool = $self->has_blank_value
