@@ -41,6 +41,8 @@ use IPC::PrettyPipe::Types -all;
 use IPC::PrettyPipe::Queue;
 use IPC::PrettyPipe::Arg::Format;
 
+use String::ShellQuote 'shell_quote';
+
 with 'IPC::PrettyPipe::Queue::Element';
 
 IPC::PrettyPipe::Arg::Format
@@ -116,6 +118,8 @@ sub BUILD {
     return;
 }
 
+sub quoted_cmd {  shell_quote( $_[0]->cmd )  }
+
 sub add {
 
     my $self = shift;
@@ -364,7 +368,7 @@ __END__
 
 =head1 NAME
 
-B<IPC::PrettyPipe::Cmd> - A command in an B<L<IPC::PrettyPipe>> pipeline
+B<IPC::PrettyPipe::Cmd> - A command in an B<IPC::PrettyPipe> pipeline
 
 =head1 SYNOPSIS
 
@@ -467,7 +471,7 @@ Its elements are processed with the B<L</ffadd>> method.
 
 =back
 
-=item argpfx, argsep
+=item C<argpfx>, C<argsep>
 
 I<Optional>.  The default prefix and separation attributes for
 command arguments.  See B<L<IPC::PrettyPipe::Arg>> for more
@@ -548,10 +552,10 @@ This will override the format attributes for this argument only.
 
 =item B<args>
 
-  $args = $cmd->args
+  $args = $cmd->args;
 
-Returns an B<L<IPC::PrettyPipe::Queue>> object containing the
-arguments associated with the command.
+Return a B<L<IPC::PrettyPipe::Queue>> object containing the
+B<L<IPC::PrettyPipe::Arg>> objects associated with the command.
 
 =item B<argpfx>,
 
@@ -570,6 +574,13 @@ affects new, not existing, arguments;
 
 Return the name of the command.
 
+=item B<quoted_cmd>
+
+  $name = $cmd->quoted_cmd
+
+Return the name of the command, appropriately quoted for passing as a
+single word to a Bourne compatible shell.
+
 =item B<ffadd>
 
   $cmd->ffadd( @arguments );
@@ -609,7 +620,7 @@ An B<L<IPC::PrettyPipe::Stream>> object
 =item *
 
 A string which matches a stream specification
-(L<IPC::PrettyPipe::Stream::Util/Stream Specification>), which will cause
+(L<IPC::PrettyPipe::Stream::Utils/Stream Specification>), which will cause
 a new I/O stream to be attached to the command.  If the specification
 requires an additional parameter, the next value in C<@arguments> will be
 used for that parameter.
@@ -623,7 +634,7 @@ used for that parameter.
   $cmd->stream( $spec, $file );
 
 Add an I/O stream to the command.  It may be passed either a stream
-specification (L<IPC::PrettyPipe::Stream::Util/Stream Specification>)
+specification (L<IPC::PrettyPipe::Stream::Utils/Stream Specification>)
 or an B<L<IPC::PrettyPipe::Stream>> object.
 
 See B<L<IPC::PrettyPipe::Stream>> for more information.
@@ -632,8 +643,8 @@ See B<L<IPC::PrettyPipe::Stream>> for more information.
 
   $streams = $cmd->streams
 
-Return an B<L<IPC::PrettyPipe::Queue>> object containing the streams
-associated with the command.
+Return a B<L<IPC::PrettyPipe::Queue>> object containing the
+B<L<IPC::PrettyPipe::Stream>> objects associated with the command.
 
 =item B<valmatch>
 
